@@ -2,27 +2,31 @@ import asyncio
 import json
 import itertools
 import websockets
+from .utils import get_api_base_ws_uri
+
 
 class ProtocolError(Exception):
     pass
 
+
 class CredentialsError(Exception):
     pass
 
+
 class SubscriptionIterator:
     def __init__(self):
         self.queue = asyncio.Queue()
-    
+
     def enqueue_payload(self, payload):
         queue_item = ('payload', payload)
         self.queue.put_nowait(queue_item)
-    
+
     def close_iterator(self, exception):
         self.queue.put_nowait(('stop', exception))
 
     def __aiter__(self):
         return self
-    
+
     async def __anext__(self):
         queue_item = await self.queue.get()
         if queue_item[0] == 'payload':
@@ -35,6 +39,7 @@ class SubscriptionIterator:
         else:
             raise NotImplementedError()
 
+
 class StreamSeaConnection:
     def __init__(self, *, remote_host, remote_port=None, secure=False, client_id, client_secret, loop=None):
         self.client_id = client_id
@@ -44,7 +49,7 @@ class StreamSeaConnection:
         self.ensure_authenticated = self.loop.create_future()
         self.replies_map = {}
         self.msg_id_sequence = itertools.count(1)
-        self.uri = ('wss' if secure else 'ws') + f'://{remote_host}:{remote_port}/api/v1/streams'
+        self.uri = get_api_base_ws_uri(remote_host=remote_host, remote_port=remote_port, secure=secure) + '/streams'
 
     async def __aenter__(self):
         return await self
@@ -60,7 +65,7 @@ class StreamSeaConnection:
     async def __await_impl__(self):
         ws = await websockets.connect(self.uri)
         self.ensure_ws.set_result(ws)
-        
+
         auth_request_msg_json = {
             "id": next(self.msg_id_sequence),
             "action": "authenticate",
@@ -95,7 +100,7 @@ class StreamSeaConnection:
     async def send(self, message_json):
         ws = await self.ensure_ws
         await ws.send(json.dumps(message_json))
-    
+
     async def authenticated_listen(self):
         # Receive messages forever. May only be called once authentication has succeeded
         try:
@@ -112,7 +117,7 @@ class StreamSeaConnection:
     async def recv(self):
         ws = await self.ensure_ws
         return await ws.recv()
-    
+
     async def subscribe(self, stream_name):
         await self.ensure_authenticated
         msg_id = next(self.msg_id_sequence)
@@ -130,7 +135,7 @@ class StreamSeaConnection:
             "other_replies_iterator": other_replies_iterator,
         }
         await self.send(subscription_request_msg_json)
-        
+
         first_reply_json = await first_reply_future
         if first_reply_json['action'] != 'subscription':
             raise ProtocolError('Reply to a subscribe action must be a subscription action')
@@ -156,4 +161,3 @@ class StreamSeaConnection:
 
         except json.decoder.JSONDecodeError:
             raise ProtocolError('Could not decode JSON for message')
-
